"""This file re-creates the Figures presented in Section 4 of the paper

NOTE: Gurobi is required to run these functions.
"""

import numpy as np
import PWM_app as PWM
import pandas as pd

#set seed
np.random.seed(5)

#propensity score from JTPA
prop = 2/3

#set level (class G_k)
level = 1

#read in file
data = pd.io.stata.read_stata("/Users/max/Dropbox/github/SWM/jtpa2.dta")

#grab relevant columns
y = data['earnings'].values
d = data['assignmt'].values
x1 = data['prevearn'].values
x2 = data['bfeduca'].values
x2 = x2.astype(np.int)
#scale data
ys = y/10000
x1s = x1/10000
x2s = x2
#scaled and unscaled datasets
data2 = np.dstack((y,d,x2,x1))[0]
data = np.dstack((ys,d,x2s,x1s))[0]

#permute indices just incase sorted
p = np.random.permutation(len(data))
data = data[p]
data2 = data2[p]

"""
To run EWM: use PWM.EWM at desired level
To run PWM: use PWM.PWM at desired level, returns rule and penalty value
"""
gt,zt,bt = PWM.EWM(data, prop, level, message = 1)
#ct,zt,bt = PWM.PWM(data, int(len(data)/4), prop, level, 1)
zt = np.zeros(len(data))
for i in range(0, len(data), 1):
            x = data[i,2:]
            zt[i] = PWM._is_in(bt, x)

bt = np.array(bt)
bt[1:] = bt[1:]*10000 #rescale rule
print(bt)
PWM.plot_rule(data2, zt, bt)
