"""
This file runs the Monte Carlo simulations to re-create Figure 5 in the Appendix

NOTE: Gurobi is required to run these functions.
"""

import numpy as np
import PWM_sims as PWM
import time

#set seed
np.random.seed(5)

#number of Monte Carlo iterations
itera = 1

#set propensity score
prop = 0.2

#set sample size
n = 100
    
print("n",n)

opt = 21.2968

regret_PWM = np.zeros(itera)
regret_EWM2 = np.zeros(itera)
regret_EWM5 = np.zeros(itera)

start = time.time()

for i in range(0,itera,1):
    #generate data
    data = PWM.gen_data(n, prop)
    
    #compute decision rules
    gt2, zt2, bt2 = PWM.EWM(data, prop, 2, dm = 0)
    gt5, zt5, bt5 = PWM.EWM(data, prop, 5, dm = 0)
    [sim_level, rule_PWM] =  PWM.PWM(data, int(len(data)/4),prop, dm = 0) 
    
    #evaluate welfare
    evalu2 = PWM.evaluate_rule(bt2, prop, 200000)
    evalu5 = PWM.evaluate_rule(bt5, prop, 200000) 
    evalu_pwm = PWM.evaluate_rule(rule_PWM, prop, 200000)
    
    #compute discrepancy
    regret_EWM2[i] = np.max((0, opt - evalu2))
    regret_EWM5[i] = np.max((0, opt - evalu5))
    regret_PWM[i] = np.max((0, opt - evalu_pwm))
    
print("PWM regret:", np.mean(regret_PWM))
print("EWM2 regret:", np.mean(regret_EWM2))
print("EWM5 regret:", np.mean(regret_EWM5))
end = time.time()
print(end - start)
